==> haskell-crypton-x509-1.7.7-65-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-crypton-x509.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 crypton-x509
version:              1.7.7
visibility:           public
id:                   crypton-x509-1.7.7-6vuhyPxGrsd7bUuwSROapz
key:                  crypton-x509-1.7.7-6vuhyPxGrsd7bUuwSROapz
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/kazu-yamamoto/crypton-certificate
synopsis:             X509 reader and writer
description:          X509 reader and writer. please see README
category:             Data
abi:                  34b1cb4e810718866cba6180de00c018
exposed:              True
exposed-modules:      Data.X509 Data.X509.EC
hidden-modules:
    Data.X509.Internal Data.X509.CertificateChain
    Data.X509.AlgorithmIdentifier Data.X509.DistinguishedName
    Data.X509.Cert Data.X509.PublicKey Data.X509.PrivateKey
    Data.X509.Ext Data.X509.ExtensionRaw Data.X509.CRL Data.X509.OID
    Data.X509.Signed

import-dirs:          /usr/lib/ghc-9.6.6/site-local/crypton-x509-1.7.7
library-dirs:         /usr/lib/ghc-9.6.6/site-local/crypton-x509-1.7.7
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/crypton-x509-1.7.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypton-x509
hs-libraries:         HScrypton-x509-1.7.7-6vuhyPxGrsd7bUuwSROapz
depends:
    asn1-encoding-0.9.6-4rkJHO0pUeFCGFdsLyrUdt
    asn1-parse-0.9.5-DinlHyBahm8CwVodLrJ7aO
    asn1-types-0.3.4-3PelmjEeZz36Y9JkroV62e base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7
    crypton-1.0.4-8iIZddQo7Y8B1JLRcnCUbI
    hourglass-0.2.12-91uaLvWJDdFIwz6ObSsY6A
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    pem-0.2.4-G3GIG2bUe0L9P6z0Mw3OGw transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-crypton-x509/html/crypton-x509.haddock

haddock-html:         /usr/share/doc/haskell-crypton-x509/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypton-x509-1.7.7-66-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-crypton-x509.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 crypton-x509
version:              1.7.7
visibility:           public
id:                   crypton-x509-1.7.7-EHBNyCbrbA07dcTqixBZKh
key:                  crypton-x509-1.7.7-EHBNyCbrbA07dcTqixBZKh
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/kazu-yamamoto/crypton-certificate
synopsis:             X509 reader and writer
description:          X509 reader and writer. please see README
category:             Data
abi:                  5a385487ae1d9f63d53d72acdfe332b0
exposed:              True
exposed-modules:      Data.X509 Data.X509.EC
hidden-modules:
    Data.X509.Internal Data.X509.CertificateChain
    Data.X509.AlgorithmIdentifier Data.X509.DistinguishedName
    Data.X509.Cert Data.X509.PublicKey Data.X509.PrivateKey
    Data.X509.Ext Data.X509.ExtensionRaw Data.X509.CRL Data.X509.OID
    Data.X509.Signed

import-dirs:          /usr/lib/ghc-9.6.6/site-local/crypton-x509-1.7.7
library-dirs:         /usr/lib/ghc-9.6.6/site-local/crypton-x509-1.7.7
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/crypton-x509-1.7.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypton-x509
hs-libraries:         HScrypton-x509-1.7.7-EHBNyCbrbA07dcTqixBZKh
depends:
    asn1-encoding-0.9.6-AvYB4EqU5FZ22SW1977wl2
    asn1-parse-0.9.5-LqiPLGikdcT8z5Jgo7EAEK
    asn1-types-0.3.4-ADD71RCSNC29zatyMQHS9E base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7
    crypton-1.0.4-37TsNQoV8Vb5042LlXS4MC
    hourglass-0.2.12-7lfqScrKovN8Qrggv3biyr
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    pem-0.2.4-JftdqSGONQgFF4koR6mcjr transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-crypton-x509/html/crypton-x509.haddock

haddock-html:         /usr/share/doc/haskell-crypton-x509/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
